@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,26 +16,28 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.webrisk_v1.types import webrisk
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import WebRiskServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import WebRiskServiceGrpcAsyncIOTransport
+
+from google.cloud.webrisk_v1.types import webrisk
+
 from .client import WebRiskServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, WebRiskServiceTransport
+from .transports.grpc_asyncio import WebRiskServiceGrpcAsyncIOTransport
 
 
 class WebRiskServiceAsyncClient:
@@ -222,14 +224,13 @@ class WebRiskServiceAsyncClient:
         ThreatList databases, this method needs to be called
         once for each list.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
-            def sample_compute_threat_list_diff():
+            async def sample_compute_threat_list_diff():
                 # Create a client
-                client = webrisk_v1.WebRiskServiceClient()
+                client = webrisk_v1.WebRiskServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = webrisk_v1.ComputeThreatListDiffRequest(
@@ -237,7 +238,7 @@ class WebRiskServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.compute_threat_list_diff(request=request)
+                response = await client.compute_threat_list_diff(request=request)
 
                 # Handle the response
                 print(response)
@@ -324,7 +325,12 @@ class WebRiskServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -346,14 +352,13 @@ class WebRiskServiceAsyncClient:
         not found on any of the requested ThreatList an empty
         response will be returned.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
-            def sample_search_uris():
+            async def sample_search_uris():
                 # Create a client
-                client = webrisk_v1.WebRiskServiceClient()
+                client = webrisk_v1.WebRiskServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = webrisk_v1.SearchUrisRequest(
@@ -362,7 +367,7 @@ class WebRiskServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.search_uris(request=request)
+                response = await client.search_uris(request=request)
 
                 # Handle the response
                 print(response)
@@ -434,7 +439,12 @@ class WebRiskServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -456,14 +466,13 @@ class WebRiskServiceAsyncClient:
         query this method to determine if there is a full hash
         match of a threat.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
-            def sample_search_hashes():
+            async def sample_search_hashes():
                 # Create a client
-                client = webrisk_v1.WebRiskServiceClient()
+                client = webrisk_v1.WebRiskServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = webrisk_v1.SearchHashesRequest(
@@ -471,7 +480,7 @@ class WebRiskServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.search_hashes(request=request)
+                response = await client.search_hashes(request=request)
 
                 # Handle the response
                 print(response)
@@ -545,7 +554,12 @@ class WebRiskServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -569,14 +583,13 @@ class WebRiskServiceAsyncClient:
         in the future. Only projects with CREATE_SUBMISSION_USERS
         visibility can use this method.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
-            def sample_create_submission():
+            async def sample_create_submission():
                 # Create a client
-                client = webrisk_v1.WebRiskServiceClient()
+                client = webrisk_v1.WebRiskServiceAsyncClient()
 
                 # Initialize request argument(s)
                 submission = webrisk_v1.Submission()
@@ -588,7 +601,7 @@ class WebRiskServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_submission(request=request)
+                response = await client.create_submission(request=request)
 
                 # Handle the response
                 print(response)
@@ -659,7 +672,12 @@ class WebRiskServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -673,7 +691,9 @@ class WebRiskServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-webrisk",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-webrisk",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
