@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,27 +16,29 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.webrisk_v1.types import webrisk
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import WebRiskServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.webrisk_v1.types import webrisk
+
+from .transports.base import DEFAULT_CLIENT_INFO, WebRiskServiceTransport
 from .transports.grpc import WebRiskServiceGrpcTransport
 from .transports.grpc_asyncio import WebRiskServiceGrpcAsyncIOTransport
 
@@ -55,7 +57,10 @@ class WebRiskServiceClientMeta(type):
     _transport_registry["grpc"] = WebRiskServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = WebRiskServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[WebRiskServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[WebRiskServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -162,7 +167,9 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -175,9 +182,13 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -186,9 +197,13 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -197,9 +212,13 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -208,10 +227,14 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -383,6 +406,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def compute_threat_list_diff(
@@ -405,9 +429,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         ThreatList databases, this method needs to be called
         once for each list.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
@@ -498,7 +520,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.compute_threat_list_diff]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -520,9 +547,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         not found on any of the requested ThreatList an empty
         response will be returned.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
@@ -599,7 +624,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.search_uris]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -621,9 +651,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         query this method to determine if there is a full hash
         match of a threat.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
@@ -701,7 +729,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         rpc = self._transport._wrapped_methods[self._transport.search_hashes]
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -725,9 +758,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         in the future. Only projects with CREATE_SUBMISSION_USERS
         visibility can use this method.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1
 
@@ -816,7 +847,12 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -837,7 +873,9 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-webrisk",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-webrisk",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
