@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,26 +16,28 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.webrisk_v1beta1.types import webrisk
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import WebRiskServiceV1Beta1Transport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import WebRiskServiceV1Beta1GrpcAsyncIOTransport
+
+from google.cloud.webrisk_v1beta1.types import webrisk
+
 from .client import WebRiskServiceV1Beta1Client
+from .transports.base import DEFAULT_CLIENT_INFO, WebRiskServiceV1Beta1Transport
+from .transports.grpc_asyncio import WebRiskServiceV1Beta1GrpcAsyncIOTransport
 
 
 class WebRiskServiceV1Beta1AsyncClient:
@@ -218,13 +220,13 @@ class WebRiskServiceV1Beta1AsyncClient:
     ) -> webrisk.ComputeThreatListDiffResponse:
         r"""Gets the most recent threat list diffs.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1beta1
 
-            def sample_compute_threat_list_diff():
+            async def sample_compute_threat_list_diff():
                 # Create a client
-                client = webrisk_v1beta1.WebRiskServiceV1Beta1Client()
+                client = webrisk_v1beta1.WebRiskServiceV1Beta1AsyncClient()
 
                 # Initialize request argument(s)
                 request = webrisk_v1beta1.ComputeThreatListDiffRequest(
@@ -232,7 +234,7 @@ class WebRiskServiceV1Beta1AsyncClient:
                 )
 
                 # Make the request
-                response = client.compute_threat_list_diff(request=request)
+                response = await client.compute_threat_list_diff(request=request)
 
                 # Handle the response
                 print(response)
@@ -311,7 +313,12 @@ class WebRiskServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -329,14 +336,13 @@ class WebRiskServiceV1Beta1AsyncClient:
         r"""This method is used to check whether a URI is on a
         given threatList.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1beta1
 
-            def sample_search_uris():
+            async def sample_search_uris():
                 # Create a client
-                client = webrisk_v1beta1.WebRiskServiceV1Beta1Client()
+                client = webrisk_v1beta1.WebRiskServiceV1Beta1AsyncClient()
 
                 # Initialize request argument(s)
                 request = webrisk_v1beta1.SearchUrisRequest(
@@ -345,7 +351,7 @@ class WebRiskServiceV1Beta1AsyncClient:
                 )
 
                 # Make the request
-                response = client.search_uris(request=request)
+                response = await client.search_uris(request=request)
 
                 # Handle the response
                 print(response)
@@ -416,7 +422,12 @@ class WebRiskServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -438,14 +449,13 @@ class WebRiskServiceV1Beta1AsyncClient:
         query this method to determine if there is a full hash
         match of a threat.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import webrisk_v1beta1
 
-            def sample_search_hashes():
+            async def sample_search_hashes():
                 # Create a client
-                client = webrisk_v1beta1.WebRiskServiceV1Beta1Client()
+                client = webrisk_v1beta1.WebRiskServiceV1Beta1AsyncClient()
 
                 # Initialize request argument(s)
                 request = webrisk_v1beta1.SearchHashesRequest(
@@ -453,7 +463,7 @@ class WebRiskServiceV1Beta1AsyncClient:
                 )
 
                 # Make the request
-                response = client.search_hashes(request=request)
+                response = await client.search_hashes(request=request)
 
                 # Handle the response
                 print(response)
@@ -526,7 +536,12 @@ class WebRiskServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -540,7 +555,9 @@ class WebRiskServiceV1Beta1AsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-webrisk",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-webrisk",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
