@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,30 +14,35 @@
 # limitations under the License.
 #
 import os
-import mock
 
-import grpc
-from grpc.experimental import aio
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.webrisk_v1.services.web_risk_service import WebRiskServiceAsyncClient
-from google.cloud.webrisk_v1.services.web_risk_service import WebRiskServiceClient
-from google.cloud.webrisk_v1.services.web_risk_service import transports
-from google.cloud.webrisk_v1.types import webrisk
 from google.oauth2 import service_account
 from google.protobuf import timestamp_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.webrisk_v1.services.web_risk_service import (
+    WebRiskServiceAsyncClient,
+    WebRiskServiceClient,
+    transports,
+)
+from google.cloud.webrisk_v1.types import webrisk
 
 
 def client_cert_source_callback():
@@ -85,20 +90,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [WebRiskServiceClient, WebRiskServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (WebRiskServiceClient, "grpc"),
+        (WebRiskServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_web_risk_service_client_from_service_account_info(client_class):
+def test_web_risk_service_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "webrisk.googleapis.com:443"
+        assert client.transport._host == ("webrisk.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -127,23 +138,33 @@ def test_web_risk_service_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [WebRiskServiceClient, WebRiskServiceAsyncClient,]
+    "client_class,transport_name",
+    [
+        (WebRiskServiceClient, "grpc"),
+        (WebRiskServiceAsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_web_risk_service_client_from_service_account_file(client_class):
+def test_web_risk_service_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "webrisk.googleapis.com:443"
+        assert client.transport._host == ("webrisk.googleapis.com:443")
 
 
 def test_web_risk_service_client_get_transport_class():
@@ -206,6 +227,7 @@ def test_web_risk_service_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -223,6 +245,7 @@ def test_web_risk_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -240,6 +263,7 @@ def test_web_risk_service_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -269,6 +293,25 @@ def test_web_risk_service_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -336,6 +379,7 @@ def test_web_risk_service_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -370,6 +414,7 @@ def test_web_risk_service_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -392,6 +437,7 @@ def test_web_risk_service_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -491,7 +537,9 @@ def test_web_risk_service_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -504,6 +552,7 @@ def test_web_risk_service_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -542,6 +591,7 @@ def test_web_risk_service_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -562,6 +612,7 @@ def test_web_risk_service_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -600,6 +651,7 @@ def test_web_risk_service_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -631,10 +683,17 @@ def test_web_risk_service_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [webrisk.ComputeThreatListDiffRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        webrisk.ComputeThreatListDiffRequest,
+        dict,
+    ],
+)
 def test_compute_threat_list_diff(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -670,7 +729,8 @@ def test_compute_threat_list_diff_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -688,7 +748,8 @@ async def test_compute_threat_list_diff_async(
     transport: str = "grpc_asyncio", request_type=webrisk.ComputeThreatListDiffRequest
 ):
     client = WebRiskServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -728,7 +789,9 @@ async def test_compute_threat_list_diff_async_from_dict():
 
 
 def test_compute_threat_list_diff_flattened():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -764,7 +827,9 @@ def test_compute_threat_list_diff_flattened():
 
 
 def test_compute_threat_list_diff_flattened_error():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -841,10 +906,17 @@ async def test_compute_threat_list_diff_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [webrisk.SearchUrisRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        webrisk.SearchUrisRequest,
+        dict,
+    ],
+)
 def test_search_uris(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -870,7 +942,8 @@ def test_search_uris_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -886,7 +959,8 @@ async def test_search_uris_async(
     transport: str = "grpc_asyncio", request_type=webrisk.SearchUrisRequest
 ):
     client = WebRiskServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -916,7 +990,9 @@ async def test_search_uris_async_from_dict():
 
 
 def test_search_uris_flattened():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.search_uris), "__call__") as call:
@@ -925,7 +1001,8 @@ def test_search_uris_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_uris(
-            uri="uri_value", threat_types=[webrisk.ThreatType.MALWARE],
+            uri="uri_value",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -941,7 +1018,9 @@ def test_search_uris_flattened():
 
 
 def test_search_uris_flattened_error():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -970,7 +1049,8 @@ async def test_search_uris_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_uris(
-            uri="uri_value", threat_types=[webrisk.ThreatType.MALWARE],
+            uri="uri_value",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -1001,10 +1081,17 @@ async def test_search_uris_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [webrisk.SearchHashesRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        webrisk.SearchHashesRequest,
+        dict,
+    ],
+)
 def test_search_hashes(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1030,7 +1117,8 @@ def test_search_hashes_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1046,7 +1134,8 @@ async def test_search_hashes_async(
     transport: str = "grpc_asyncio", request_type=webrisk.SearchHashesRequest
 ):
     client = WebRiskServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1076,7 +1165,9 @@ async def test_search_hashes_async_from_dict():
 
 
 def test_search_hashes_flattened():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.search_hashes), "__call__") as call:
@@ -1085,7 +1176,8 @@ def test_search_hashes_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_hashes(
-            hash_prefix=b"hash_prefix_blob", threat_types=[webrisk.ThreatType.MALWARE],
+            hash_prefix=b"hash_prefix_blob",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -1101,7 +1193,9 @@ def test_search_hashes_flattened():
 
 
 def test_search_hashes_flattened_error():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1130,7 +1224,8 @@ async def test_search_hashes_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_hashes(
-            hash_prefix=b"hash_prefix_blob", threat_types=[webrisk.ThreatType.MALWARE],
+            hash_prefix=b"hash_prefix_blob",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -1161,10 +1256,17 @@ async def test_search_hashes_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [webrisk.CreateSubmissionRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        webrisk.CreateSubmissionRequest,
+        dict,
+    ],
+)
 def test_create_submission(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1176,7 +1278,9 @@ def test_create_submission(request_type, transport: str = "grpc"):
         type(client.transport.create_submission), "__call__"
     ) as call:
         # Designate an appropriate return value for the call.
-        call.return_value = webrisk.Submission(uri="uri_value",)
+        call.return_value = webrisk.Submission(
+            uri="uri_value",
+        )
         response = client.create_submission(request)
 
         # Establish that the underlying gRPC stub method was called.
@@ -1193,7 +1297,8 @@ def test_create_submission_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = WebRiskServiceClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1211,7 +1316,8 @@ async def test_create_submission_async(
     transport: str = "grpc_asyncio", request_type=webrisk.CreateSubmissionRequest
 ):
     client = WebRiskServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1224,7 +1330,9 @@ async def test_create_submission_async(
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            webrisk.Submission(uri="uri_value",)
+            webrisk.Submission(
+                uri="uri_value",
+            )
         )
         response = await client.create_submission(request)
 
@@ -1244,13 +1352,15 @@ async def test_create_submission_async_from_dict():
 
 
 def test_create_submission_field_headers():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
     request = webrisk.CreateSubmissionRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1266,7 +1376,10 @@ def test_create_submission_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
@@ -1279,7 +1392,7 @@ async def test_create_submission_field_headers_async():
     # a field header. Set these to a non-empty value.
     request = webrisk.CreateSubmissionRequest()
 
-    request.parent = "parent/value"
+    request.parent = "parent_value"
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1295,11 +1408,16 @@ async def test_create_submission_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent_value",
+    ) in kw["metadata"]
 
 
 def test_create_submission_flattened():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -1310,7 +1428,8 @@ def test_create_submission_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.create_submission(
-            parent="parent_value", submission=webrisk.Submission(uri="uri_value"),
+            parent="parent_value",
+            submission=webrisk.Submission(uri="uri_value"),
         )
 
         # Establish that the underlying call was made with the expected
@@ -1326,7 +1445,9 @@ def test_create_submission_flattened():
 
 
 def test_create_submission_flattened_error():
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -1355,7 +1476,8 @@ async def test_create_submission_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.create_submission(
-            parent="parent_value", submission=webrisk.Submission(uri="uri_value"),
+            parent="parent_value",
+            submission=webrisk.Submission(uri="uri_value"),
         )
 
         # Establish that the underlying call was made with the expected
@@ -1393,7 +1515,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = WebRiskServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1413,7 +1536,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = WebRiskServiceClient(client_options=options, transport=transport,)
+        client = WebRiskServiceClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -1429,7 +1555,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = WebRiskServiceClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1472,10 +1599,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = WebRiskServiceClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = WebRiskServiceClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.WebRiskServiceGrpcTransport,)
+    client = WebRiskServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.WebRiskServiceGrpcTransport,
+    )
 
 
 def test_web_risk_service_base_transport_error():
@@ -1512,6 +1657,14 @@ def test_web_risk_service_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_web_risk_service_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1523,7 +1676,8 @@ def test_web_risk_service_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.WebRiskServiceTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1576,6 +1730,28 @@ def test_web_risk_service_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.WebRiskServiceGrpcTransport,
+        transports.WebRiskServiceGrpcAsyncIOTransport,
+    ],
+)
+def test_web_risk_service_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1656,24 +1832,40 @@ def test_web_risk_service_grpc_transport_client_cert_source_for_mtls(transport_c
             )
 
 
-def test_web_risk_service_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_web_risk_service_host_no_port(transport_name):
     client = WebRiskServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="webrisk.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "webrisk.googleapis.com:443"
+    assert client.transport._host == ("webrisk.googleapis.com:443")
 
 
-def test_web_risk_service_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_web_risk_service_host_with_port(transport_name):
     client = WebRiskServiceClient(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="webrisk.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "webrisk.googleapis.com:8000"
+    assert client.transport._host == ("webrisk.googleapis.com:8000")
 
 
 def test_web_risk_service_grpc_transport_channel():
@@ -1681,7 +1873,8 @@ def test_web_risk_service_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.WebRiskServiceGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1693,7 +1886,8 @@ def test_web_risk_service_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.WebRiskServiceGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1822,7 +2016,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = WebRiskServiceClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1840,7 +2036,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = WebRiskServiceClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1858,7 +2056,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = WebRiskServiceClient.common_project_path(project)
     assert expected == actual
 
@@ -1878,7 +2078,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = WebRiskServiceClient.common_location_path(project, location)
     assert expected == actual
@@ -1903,7 +2104,8 @@ def test_client_with_default_client_info():
         transports.WebRiskServiceTransport, "_prep_wrapped_messages"
     ) as prep:
         client = WebRiskServiceClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1912,7 +2114,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = WebRiskServiceClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1920,7 +2123,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = WebRiskServiceAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
@@ -1990,4 +2194,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
