@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,34 +14,35 @@
 # limitations under the License.
 #
 import os
-import mock
 
-import grpc
-from grpc.experimental import aio
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
+
 import math
-import pytest
-from proto.marshal.rules.dates import DurationRule, TimestampRule
-
 
+from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
-from google.api_core import grpc_helpers
-from google.api_core import grpc_helpers_async
-from google.api_core import path_template
+import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
-from google.cloud.webrisk_v1beta1.services.web_risk_service_v1_beta1 import (
-    WebRiskServiceV1Beta1AsyncClient,
-)
-from google.cloud.webrisk_v1beta1.services.web_risk_service_v1_beta1 import (
-    WebRiskServiceV1Beta1Client,
-)
-from google.cloud.webrisk_v1beta1.services.web_risk_service_v1_beta1 import transports
-from google.cloud.webrisk_v1beta1.types import webrisk
 from google.oauth2 import service_account
 from google.protobuf import timestamp_pb2  # type: ignore
-import google.auth
+import grpc
+from grpc.experimental import aio
+from proto.marshal.rules.dates import DurationRule, TimestampRule
+import pytest
+
+from google.cloud.webrisk_v1beta1.services.web_risk_service_v1_beta1 import (
+    WebRiskServiceV1Beta1AsyncClient,
+    WebRiskServiceV1Beta1Client,
+    transports,
+)
+from google.cloud.webrisk_v1beta1.types import webrisk
 
 
 def client_cert_source_callback():
@@ -90,20 +91,26 @@ def test__get_default_mtls_endpoint():
 
 
 @pytest.mark.parametrize(
-    "client_class", [WebRiskServiceV1Beta1Client, WebRiskServiceV1Beta1AsyncClient,]
+    "client_class,transport_name",
+    [
+        (WebRiskServiceV1Beta1Client, "grpc"),
+        (WebRiskServiceV1Beta1AsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_web_risk_service_v1_beta1_client_from_service_account_info(client_class):
+def test_web_risk_service_v1_beta1_client_from_service_account_info(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_info"
     ) as factory:
         factory.return_value = creds
         info = {"valid": True}
-        client = client_class.from_service_account_info(info)
+        client = client_class.from_service_account_info(info, transport=transport_name)
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "webrisk.googleapis.com:443"
+        assert client.transport._host == ("webrisk.googleapis.com:443")
 
 
 @pytest.mark.parametrize(
@@ -132,23 +139,33 @@ def test_web_risk_service_v1_beta1_client_service_account_always_use_jwt(
 
 
 @pytest.mark.parametrize(
-    "client_class", [WebRiskServiceV1Beta1Client, WebRiskServiceV1Beta1AsyncClient,]
+    "client_class,transport_name",
+    [
+        (WebRiskServiceV1Beta1Client, "grpc"),
+        (WebRiskServiceV1Beta1AsyncClient, "grpc_asyncio"),
+    ],
 )
-def test_web_risk_service_v1_beta1_client_from_service_account_file(client_class):
+def test_web_risk_service_v1_beta1_client_from_service_account_file(
+    client_class, transport_name
+):
     creds = ga_credentials.AnonymousCredentials()
     with mock.patch.object(
         service_account.Credentials, "from_service_account_file"
     ) as factory:
         factory.return_value = creds
-        client = client_class.from_service_account_file("dummy/file/path.json")
+        client = client_class.from_service_account_file(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        client = client_class.from_service_account_json("dummy/file/path.json")
+        client = client_class.from_service_account_json(
+            "dummy/file/path.json", transport=transport_name
+        )
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == "webrisk.googleapis.com:443"
+        assert client.transport._host == ("webrisk.googleapis.com:443")
 
 
 def test_web_risk_service_v1_beta1_client_get_transport_class():
@@ -215,6 +232,7 @@ def test_web_risk_service_v1_beta1_client_client_options(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -232,6 +250,7 @@ def test_web_risk_service_v1_beta1_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -249,6 +268,7 @@ def test_web_risk_service_v1_beta1_client_client_options(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -278,6 +298,25 @@ def test_web_risk_service_v1_beta1_client_client_options(
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -355,6 +394,7 @@ def test_web_risk_service_v1_beta1_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -389,6 +429,7 @@ def test_web_risk_service_v1_beta1_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -411,6 +452,7 @@ def test_web_risk_service_v1_beta1_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -516,7 +558,9 @@ def test_web_risk_service_v1_beta1_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -529,6 +573,7 @@ def test_web_risk_service_v1_beta1_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -567,6 +612,7 @@ def test_web_risk_service_v1_beta1_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -587,6 +633,7 @@ def test_web_risk_service_v1_beta1_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -625,6 +672,7 @@ def test_web_risk_service_v1_beta1_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -656,10 +704,17 @@ def test_web_risk_service_v1_beta1_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [webrisk.ComputeThreatListDiffRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        webrisk.ComputeThreatListDiffRequest,
+        dict,
+    ],
+)
 def test_compute_threat_list_diff(request_type, transport: str = "grpc"):
     client = WebRiskServiceV1Beta1Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -695,7 +750,8 @@ def test_compute_threat_list_diff_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = WebRiskServiceV1Beta1Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -713,7 +769,8 @@ async def test_compute_threat_list_diff_async(
     transport: str = "grpc_asyncio", request_type=webrisk.ComputeThreatListDiffRequest
 ):
     client = WebRiskServiceV1Beta1AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -870,10 +927,17 @@ async def test_compute_threat_list_diff_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [webrisk.SearchUrisRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        webrisk.SearchUrisRequest,
+        dict,
+    ],
+)
 def test_search_uris(request_type, transport: str = "grpc"):
     client = WebRiskServiceV1Beta1Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -899,7 +963,8 @@ def test_search_uris_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = WebRiskServiceV1Beta1Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -915,7 +980,8 @@ async def test_search_uris_async(
     transport: str = "grpc_asyncio", request_type=webrisk.SearchUrisRequest
 ):
     client = WebRiskServiceV1Beta1AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -956,7 +1022,8 @@ def test_search_uris_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_uris(
-            uri="uri_value", threat_types=[webrisk.ThreatType.MALWARE],
+            uri="uri_value",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -1003,7 +1070,8 @@ async def test_search_uris_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_uris(
-            uri="uri_value", threat_types=[webrisk.ThreatType.MALWARE],
+            uri="uri_value",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -1034,10 +1102,17 @@ async def test_search_uris_flattened_error_async():
         )
 
 
-@pytest.mark.parametrize("request_type", [webrisk.SearchHashesRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        webrisk.SearchHashesRequest,
+        dict,
+    ],
+)
 def test_search_hashes(request_type, transport: str = "grpc"):
     client = WebRiskServiceV1Beta1Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1063,7 +1138,8 @@ def test_search_hashes_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = WebRiskServiceV1Beta1Client(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -1079,7 +1155,8 @@ async def test_search_hashes_async(
     transport: str = "grpc_asyncio", request_type=webrisk.SearchHashesRequest
 ):
     client = WebRiskServiceV1Beta1AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -1120,7 +1197,8 @@ def test_search_hashes_flattened():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         client.search_hashes(
-            hash_prefix=b"hash_prefix_blob", threat_types=[webrisk.ThreatType.MALWARE],
+            hash_prefix=b"hash_prefix_blob",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -1167,7 +1245,8 @@ async def test_search_hashes_flattened_async():
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
         response = await client.search_hashes(
-            hash_prefix=b"hash_prefix_blob", threat_types=[webrisk.ThreatType.MALWARE],
+            hash_prefix=b"hash_prefix_blob",
+            threat_types=[webrisk.ThreatType.MALWARE],
         )
 
         # Establish that the underlying call was made with the expected
@@ -1205,7 +1284,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = WebRiskServiceV1Beta1Client(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -1226,7 +1306,8 @@ def test_credentials_transport_error():
     options.api_key = "api_key"
     with pytest.raises(ValueError):
         client = WebRiskServiceV1Beta1Client(
-            client_options=options, transport=transport,
+            client_options=options,
+            transport=transport,
         )
 
     # It is an error to provide an api_key and a credential.
@@ -1243,7 +1324,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = WebRiskServiceV1Beta1Client(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -1286,12 +1368,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = WebRiskServiceV1Beta1Client.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
     client = WebRiskServiceV1Beta1Client(
         credentials=ga_credentials.AnonymousCredentials(),
     )
-    assert isinstance(client.transport, transports.WebRiskServiceV1Beta1GrpcTransport,)
+    assert isinstance(
+        client.transport,
+        transports.WebRiskServiceV1Beta1GrpcTransport,
+    )
 
 
 def test_web_risk_service_v1_beta1_base_transport_error():
@@ -1327,6 +1425,14 @@ def test_web_risk_service_v1_beta1_base_transport():
     with pytest.raises(NotImplementedError):
         transport.close()
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_web_risk_service_v1_beta1_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1338,7 +1444,8 @@ def test_web_risk_service_v1_beta1_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.WebRiskServiceV1Beta1Transport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1391,6 +1498,28 @@ def test_web_risk_service_v1_beta1_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.WebRiskServiceV1Beta1GrpcTransport,
+        transports.WebRiskServiceV1Beta1GrpcAsyncIOTransport,
+    ],
+)
+def test_web_risk_service_v1_beta1_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -1475,24 +1604,40 @@ def test_web_risk_service_v1_beta1_grpc_transport_client_cert_source_for_mtls(
             )
 
 
-def test_web_risk_service_v1_beta1_host_no_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_web_risk_service_v1_beta1_host_no_port(transport_name):
     client = WebRiskServiceV1Beta1Client(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="webrisk.googleapis.com"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "webrisk.googleapis.com:443"
+    assert client.transport._host == ("webrisk.googleapis.com:443")
 
 
-def test_web_risk_service_v1_beta1_host_with_port():
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
+def test_web_risk_service_v1_beta1_host_with_port(transport_name):
     client = WebRiskServiceV1Beta1Client(
         credentials=ga_credentials.AnonymousCredentials(),
         client_options=client_options.ClientOptions(
             api_endpoint="webrisk.googleapis.com:8000"
         ),
+        transport=transport_name,
     )
-    assert client.transport._host == "webrisk.googleapis.com:8000"
+    assert client.transport._host == ("webrisk.googleapis.com:8000")
 
 
 def test_web_risk_service_v1_beta1_grpc_transport_channel():
@@ -1500,7 +1645,8 @@ def test_web_risk_service_v1_beta1_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.WebRiskServiceV1Beta1GrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1512,7 +1658,8 @@ def test_web_risk_service_v1_beta1_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.WebRiskServiceV1Beta1GrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1641,7 +1788,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = WebRiskServiceV1Beta1Client.common_folder_path(folder)
     assert expected == actual
 
@@ -1659,7 +1808,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = WebRiskServiceV1Beta1Client.common_organization_path(organization)
     assert expected == actual
 
@@ -1677,7 +1828,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = WebRiskServiceV1Beta1Client.common_project_path(project)
     assert expected == actual
 
@@ -1697,7 +1850,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = WebRiskServiceV1Beta1Client.common_location_path(project, location)
     assert expected == actual
@@ -1722,7 +1876,8 @@ def test_client_with_default_client_info():
         transports.WebRiskServiceV1Beta1Transport, "_prep_wrapped_messages"
     ) as prep:
         client = WebRiskServiceV1Beta1Client(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1731,7 +1886,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = WebRiskServiceV1Beta1Client.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1739,7 +1895,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = WebRiskServiceV1Beta1AsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
@@ -1812,4 +1969,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
